/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.logcat;

import com.intellij.util.ArrayUtil;
import net.jcip.annotations.ThreadSafe;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

/**
 * A thread-safe collection of error strings reported by Android logcat.
 */
@ThreadSafe
public final class AdbErrors {
  private AdbErrors() {
  }

  private static volatile List<String> ourAdbErrorList;

  @NotNull
  public static synchronized String[] getErrors() {
    return ourAdbErrorList != null ? ArrayUtil.toStringArray(ourAdbErrorList) : ArrayUtil.EMPTY_STRING_ARRAY;
  }

  public static synchronized void clear() {
    if (ourAdbErrorList != null) {
      ourAdbErrorList.clear();
    }
  }

  public static synchronized void reportError(@NotNull String message, @Nullable String tag) {
    final String fullMessage = tag != null ? tag + ": " + message : message;
    if (ourAdbErrorList == null) {
      ourAdbErrorList = new ArrayList<String>();
    }
    ourAdbErrorList.add(fullMessage);
  }
}
